# @singletonar/intellidrone-api-client-js

JavaScript client for Intellidrone API designed by [Singleton](http://singleton.com.ar). You  can find out more about Swagger at [Singleton Web Page](http://singleton.com.ar) or on [Intellidrone Web Page](http://robotagro.com).
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.1

For more information, please visit [http://singleton.com.ar/soporte](http://singleton.com.ar/soporte)

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

If the library was published, then install it via:

```shell
npm install @singletonar/intellidrone-api-client-js --save
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing
into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

Finally, switch to the directory you want to use your @singletonar/intellidrone-api-client-js from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

You should now be able to `require('@singletonar/intellidrone-api-client-js')` in javascript files from the directory you ran the last command above from.

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`, perform the following (assuming *main.js* is your entry file, that's to say your javascript file where you actually use this library):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var intellidrone_api_client_js = require('@singletonar/intellidrone-api-client-js');

var defaultClient = intellidrone_api_client_js.ApiClient.instance;

// Configure API key authorization: appToken
var appToken = defaultClient.authentications['appToken'];
appToken.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//appToken.apiKeyPrefix['x_app_id'] = "Token"

// Configure API key authorization: userToken
var userToken = defaultClient.authentications['userToken'];
userToken.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//userToken.apiKeyPrefix['x_user_key'] = "Token"

var api = new intellidrone_api_client_js.ActividadesApi()

var actividad = new intellidrone_api_client_js.Actividades(); // {Actividades}

api.addActividad(actividad).then(function(data) {
  console.log('API called successfully. Returned data: ' + data);
}, function(error) {
  console.error(error);
});


```

## Documentation for API Endpoints

All URIs are relative to *http://web.robotagro.com/api/latest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*intellidrone_api_client_js.ActividadesApi* | [**addActividad**](docs/ActividadesApi.md#addActividad) | **POST** /Actividades | Add one Actividad.
*intellidrone_api_client_js.ActividadesApi* | [**addActividades**](docs/ActividadesApi.md#addActividades) | **POST** /Actividades/upload | Add actividades from a file.
*intellidrone_api_client_js.ActividadesApi* | [**deleteActividad**](docs/ActividadesApi.md#deleteActividad) | **DELETE** /Actividades/{id} | Delete one Actividad.
*intellidrone_api_client_js.ActividadesApi* | [**editActividad**](docs/ActividadesApi.md#editActividad) | **PUT** /Actividades | Edit one Actividad.
*intellidrone_api_client_js.ActividadesApi* | [**getActividadById**](docs/ActividadesApi.md#getActividadById) | **GET** /Actividades/{id} | Get one Actividad.
*intellidrone_api_client_js.ActividadesApi* | [**getActividades**](docs/ActividadesApi.md#getActividades) | **GET** /Actividades | Get all Actividades.
*intellidrone_api_client_js.LotesApi* | [**addLote**](docs/LotesApi.md#addLote) | **POST** /Lotes | Add one lote.
*intellidrone_api_client_js.LotesApi* | [**deleteLote**](docs/LotesApi.md#deleteLote) | **DELETE** /Lotes/{id} | Delete one lote.
*intellidrone_api_client_js.LotesApi* | [**editLote**](docs/LotesApi.md#editLote) | **PUT** /Lotes | Edit one lote.
*intellidrone_api_client_js.LotesApi* | [**getLoteById**](docs/LotesApi.md#getLoteById) | **GET** /Lotes/{id} | Get one lote.
*intellidrone_api_client_js.LotesApi* | [**getLotes**](docs/LotesApi.md#getLotes) | **GET** /Lotes | Get all lotes.
*intellidrone_api_client_js.UsersApi* | [**addUser**](docs/UsersApi.md#addUser) | **POST** /Users | Add one User.
*intellidrone_api_client_js.UsersApi* | [**deleteUsers**](docs/UsersApi.md#deleteUsers) | **DELETE** /Users/{id} | Delete one Users.
*intellidrone_api_client_js.UsersApi* | [**editUser**](docs/UsersApi.md#editUser) | **PUT** /Users | Edit one User.
*intellidrone_api_client_js.UsersApi* | [**getUserById**](docs/UsersApi.md#getUserById) | **GET** /Users/{id} | Get one User.
*intellidrone_api_client_js.UsersApi* | [**getUsers**](docs/UsersApi.md#getUsers) | **GET** /Users | Get all Users.
*intellidrone_api_client_js.UsersApi* | [**login**](docs/UsersApi.md#login) | **GET** /Users/Login | Logs user into the system
*intellidrone_api_client_js.UsersApi* | [**logout**](docs/UsersApi.md#logout) | **GET** /Users/Logout | Logs out current logged in user session
*intellidrone_api_client_js.VacasApi* | [**addVaca**](docs/VacasApi.md#addVaca) | **POST** /Vacas | Add one vaca.
*intellidrone_api_client_js.VacasApi* | [**deleteVaca**](docs/VacasApi.md#deleteVaca) | **DELETE** /Vacas/{id} | Delete one vaca.
*intellidrone_api_client_js.VacasApi* | [**editVaca**](docs/VacasApi.md#editVaca) | **PUT** /Vacas | Edit one vaca.
*intellidrone_api_client_js.VacasApi* | [**getVacas**](docs/VacasApi.md#getVacas) | **GET** /Vacas | Get all vacas.
*intellidrone_api_client_js.VacasApi* | [**getVacasById**](docs/VacasApi.md#getVacasById) | **GET** /Vacas/{id} | Get one vaca.

## Documentation for Models

- [intellidrone_api_client_js.Actividades](docs/Actividades.md)
- [intellidrone_api_client_js.DeletedResponse](docs/DeletedResponse.md)
- [intellidrone_api_client_js.Error](docs/Error.md)
- [intellidrone_api_client_js.Linea](docs/Linea.md)
- [intellidrone_api_client_js.Lotes](docs/Lotes.md)
- [intellidrone_api_client_js.UploadResponse](docs/UploadResponse.md)
- [intellidrone_api_client_js.Users](docs/Users.md)
- [intellidrone_api_client_js.Vacas](docs/Vacas.md)

## Documentation for Authorization

### appToken

- **Type**: API key
- **API key parameter name**: x_app_id
- **Location**: HTTP header

### userToken

- **Type**: API key
- **API key parameter name**: x_user_key
- **Location**: HTTP header
